aboutsummaryrefslogtreecommitdiff
path: root/engines/sword2/render.cpp
diff options
context:
space:
mode:
authorMax Horn2011-04-14 14:12:27 +0200
committerMax Horn2011-04-14 14:12:35 +0200
commit84184aabc00251374a181fe296487619afa779ed (patch)
tree6e635dcaf2300d979e6ad1be9a5e9e0ec653df4a /engines/sword2/render.cpp
parent64c4e65201ca3097cc25b295359683eafaf25b07 (diff)
downloadscummvm-rg350-84184aabc00251374a181fe296487619afa779ed.tar.gz
scummvm-rg350-84184aabc00251374a181fe296487619afa779ed.tar.bz2
scummvm-rg350-84184aabc00251374a181fe296487619afa779ed.zip
ALL: colour -> color
Diffstat (limited to 'engines/sword2/render.cpp')
-rw-r--r--engines/sword2/render.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/engines/sword2/render.cpp b/engines/sword2/render.cpp
index a71d503d95..a47f8abe0d 100644
--- a/engines/sword2/render.cpp
+++ b/engines/sword2/render.cpp
@@ -234,24 +234,24 @@ void Screen::scaleImageGood(byte *dst, uint16 dstPitch, uint16 dstWidth, uint16
* used for debugging.
* @param x x-coordinate of the point
* @param y y-coordinate of the point
* @param colour colour of the point
*/
-void Screen::plotPoint(int x, int y, uint8 colour) {
+void Screen::plotPoint(int x, int y, uint8 color) {
byte *buf = _buffer + MENUDEEP * RENDERWIDE;
x -= _scrollX;
y -= _scrollY;
if (x >= 0 && x < RENDERWIDE && y >= 0 && y < RENDERDEEP) {
- buf[y * RENDERWIDE + x] = colour;
+ buf[y * RENDERWIDE + x] = color;
markAsDirty(x, y + MENUDEEP, x, y + MENUDEEP);
}
}
-static void plot(int x, int y, int colour, void *data) {
+static void plot(int x, int y, int color, void *data) {
Screen *screen = (Screen *)data;
- screen->plotPoint(x, y, (uint8) colour);
+ screen->plotPoint(x, y, (uint8) color);
}
/**
@@ -260,11 +260,11 @@ static void plot(int x, int y, int colour, void *data) {
* @param y0 y-coordinate of the start point
* @param x1 x-coordinate of the end point
* @param y1 y-coordinate of the end point
* @param colour colour of the line
*/
-void Screen::drawLine(int x0, int y0, int x1, int y1, uint8 colour) {
- Graphics::drawLine(x0, y0, x1, y1, colour, &plot, this);
+void Screen::drawLine(int x0, int y0, int x1, int y1, uint8 color) {
+ Graphics::drawLine(x0, y0, x1, y1, color, &plot, this);
}
/**
@@ -234,24 +234,24 @@ void Screen::scaleImageGood(byte *dst, uint16 dstPitch, uint16 dstWidth, uint16
* @param x x-coordinate of the point
* @param y y-coordinate of the point
- * @param colour colour of the point
+ * @param color color of the point
*/
@@ -260,11 +260,11 @@ static void plot(int x, int y, int colour, void *data) {
* @param x1 x-coordinate of the end point
* @param y1 y-coordinate of the end point
- * @param colour colour of the line
+ * @param color color of the line
*/